@@ -7,7 +7,7 @@
 """
 from configparser import ConfigParser, NoSectionError, NoOptionError
 from pathlib import Path
-from typing import Any
+from typing import Any, Union
 
 from selenium import webdriver
 from selenium.webdriver.chrome.options import Options
@@ -24,7 +24,7 @@ class OptionsManager(object):
         self._conf = ConfigParser()
         self._conf.read(self.path, encoding='utf-8')
         if 'global_tmp_path' not in self.get_option('paths') or not self.get_value('paths', 'global_tmp_path'):
-            global_tmp_path = f'{str(Path(__file__).parent)}\\tmp'
+            global_tmp_path = str((Path(__file__).parent / 'tmp').absolute())
             Path(global_tmp_path).mkdir(parents=True, exist_ok=True)
             self.set_item('paths', 'global_tmp_path', global_tmp_path)
             self.save()
@@ -59,7 +59,7 @@ class OptionsManager(object):
         :return: None
         """
         path = path or Path(__file__).parent / 'configs.ini'
-        self._conf.write(open(path, 'w'))
+        self._conf.write(open(path, 'w', encoding='utf-8'))
 
 
 class DriverOptions(Options):
@@ -140,12 +140,18 @@ def _dict_to_chrome_options(options: dict) -> Options:
     return chrome_options
 
 
-def _chrome_options_to_dict(options: Options) -> dict:
+def _chrome_options_to_dict(options: Union[dict, Options, None]) -> Union[dict, None]:
+    if options is None or isinstance(options, dict):
+        return options
+
     re_dict = dict()
-    re_dict['binary_location'] = options.binary_location
-    re_dict['debugger_address'] = options.debugger_address
-    re_dict['arguments'] = options.arguments
-    re_dict['extensions'] = options.extensions
-    re_dict['experimental_options'] = options.experimental_options
-    # re_dict['capabilities'] = options.capabilities
+    if options.debugger_address:
+        re_dict['debugger_address'] = options.debugger_address
+    else:
+        re_dict['binary_location'] = options.binary_location
+        re_dict['debugger_address'] = options.debugger_address
+        re_dict['arguments'] = options.arguments
+        re_dict['extensions'] = options.extensions
+        re_dict['experimental_options'] = options.experimental_options
+        # re_dict['capabilities'] = options.capabilities
     return re_dict
