@@ -15,6 +15,7 @@ from .common import DrissionElement, get_loc_from_str, translate_loc_to_xpath
 
 class SessionElement(DrissionElement):
     """session模式的元素对象，包装了一个Element对象，并封装了常用功能"""
+
     def __init__(self, ele: Element):
         super().__init__(ele)
 
@@ -104,8 +105,15 @@ class SessionElement(DrissionElement):
         try:
             if attr == 'href':
                 # 如直接获取attr只能获取相对地址
-                for link in self._inner_ele.absolute_links:
-                    return link
+                link = self._inner_ele.attrs['href']
+                if link.startswith('?'):  # 避免当相对URL以?开头时requests-html丢失参数的bug
+                    if '?' in self.inner_ele.url:
+                        return re.sub(r'\?.*', link, self.inner_ele.url)
+                    else:
+                        return f'{self.inner_ele.url}{link}'
+                else:
+                    for link in self._inner_ele.absolute_links:
+                        return link
             elif attr == 'class':
                 class_str = ''
                 for key, i in enumerate(self._inner_ele.attrs['class']):
